==> gcstar_1.1.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/ES/GCModels/GCbooks.pm <==
{
    package GCLang::ES::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Colección de libros',
        Items => 'Libros',
        NewItem => 'Nuevo libro',
    
        Isbn => 'ISBN',
        Title => 'Título',
        Cover => 'Portada',
        Authors => 'Autores',
        Publisher => 'Editor',
        Publication => 'Fecha de edición',
        Language => 'Idioma',
        Genre => 'Género',
        Bookdescription => 'Descripción',
        Pages => 'Páginas',
        Read => 'Leído',
        Rating => 'Puntuación',
        Acquisition => 'Fecha de adquisición',
        Edition => 'Edición',
        Format => 'Formato',
        Comments => 'Comentarios',
        Url => 'Página web',
        Translator => 'Translator',
        Artist => 'Artist',

        General => 'General',
        Details => 'Detalles',

        ReadNo => 'No leído',
        ReadYes => 'Leído',
     );
}

1;

==> gcstar_1.3.2.orig.tar.gz: gcstar/lib/gcstar/GCLang/ES/GCModels/GCbooks.pm <==
{
    package GCLang::ES::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Colección de libros',
        Items => 'Libros',
        NewItem => 'Nuevo libro',
    
        Isbn => 'ISBN',
        Title => 'Título',
        Cover => 'Portada',
        Authors => 'Autores',
        Publisher => 'Editor',
        Publication => 'Fecha de edición',
        Language => 'Idioma',
        Genre => 'Género',
        Serie => 'Serie',
        Bookdescription => 'Descripción',
        Pages => 'Páginas',
        Read => 'Leído',
        Acquisition => 'Fecha de adquisición',
        Edition => 'Edición',
        Format => 'Formato',
        Comments => 'Comentarios',
        Url => 'Página web',
        Translator => 'Traductor',
        Artist => 'Artista',

        General => 'General',
        Details => 'Detalles',

        ReadNo => 'No leído',
        ReadYes => 'Leído',
     );
}

1;
